@@ -254,6 +254,17 @@ class Workspace:
 
     @classmethod
     def get(
+        cls,
+        workspace_id,
+    ):
+        url = get_api_domain() + f"workspaces/{workspace_id}"
+        headers = get_access_header()
+        response = requests.request(method="GET", url=url, headers=headers)
+        print(response.text)
+        return response
+
+    @classmethod
+    def get_user_workspace(
         cls,
         user,
         workspace_name,
@@ -266,16 +277,25 @@ class Workspace:
     @classmethod
     def status(
         cls,
-        user,
-        workspace_name,
+        workspace_id,
     ):
-        response = cls.get(user=user, workspace_name=workspace_name)
+        response = cls.get(workspace_id=workspace_id)
 
         # response = requests.Response()
         if response.status_code == HTTPStatus.OK:
             response._content = dumps({"status": loads(response.text).get("latest_build", {}).get("status")}).encode()
         return response
 
+    @classmethod
+    def get_listening_ports(
+        cls,
+        workspace_agent_id,
+    ):
+        url = get_api_domain() + f"workspaceagents/{workspace_agent_id}/listening-ports"
+        headers = get_access_header()
+        response = requests.request(method="GET", url=url, headers=headers)
+        return response
+
     @classmethod
     def create(
         cls,
